/*******************************************************************************
* File Name: MyTFTIntf_1.h
* Version 2.2
*
* Description:
*  This file provides constants and parameter values and API definition for the 
*  GraphicLCDIntf Component
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(MyTFTIntf_1_H)
#define MyTFTIntf_1_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"
#include "cypins.h"    

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#ifndef CY_PSOC5LP
    #error Component My_TFTIntf_v2_02 requires cy_boot v3.0 or later
#endif /* CY_PSOCLP */


/*************************************** 
*   Conditional Compilation Parameters
***************************************/

#define MyTFTIntf_1_BUS_WIDTH (8u)


/***************************************
*        Structure Definitions
***************************************/

#if (CY_UDB_V0)
    /* Sleep Mode API Support */
    typedef struct _MyTFTIntf_1_backupStruct
    {
        uint8 lowPulseWidth;
        uint8 highPulseWidth;
    } MyTFTIntf_1_BACKUP_STRUCT;
#endif /* (CY_UDB_V0) */


/***************************************
*        Function Prototypes            
***************************************/

void MyTFTIntf_1_Start(void)           ;
void MyTFTIntf_1_Stop(void)            ;
void MyTFTIntf_1_Write8(uint8 d_c, uint8 wrData) \
                                            ;
void MyTFTIntf_1_WriteM8(uint8 d_c, uint8* wrData, uint16 num) \
                                            ;
uint8 MyTFTIntf_1_Read8(uint8 d_c) \
                                            ;

void MyTFTIntf_1_Sleep(void)           ;
void MyTFTIntf_1_Wakeup(void)          ;
void MyTFTIntf_1_SaveConfig(void)      ;   
void MyTFTIntf_1_RestoreConfig(void)   ;
void MyTFTIntf_1_Init(void)            ;
void MyTFTIntf_1_Enable(void)          ;

#define CYGRAPHICS_START()                  MyTFTIntf_1_Start()
#define CYGRAPHICS_STOP()                   MyTFTIntf_1_Stop()
#define CYGRAPHICS_WRITE(addr, data)        MyTFTIntf_1_Write8(addr, data)
#define CYGRAPHICS_READ(addr)               MyTFTIntf_1_Read8(addr)
#define CYGRAPHICS_WRITEM(addr, data, num)  MyTFTIntf_1_WriteM8(addr, data, num)


/***************************************
*        API Prototypes            
*        from TFT.h file
***************************************/
void MyTFTIntf_1_Setup(uint8 orient);
void MyTFTIntf_1_SetCol(uint16 StartCol,uint16 EndCol);
void MyTFTIntf_1_SetRow(uint16 StartRow,uint16 EndRow);
void MyTFTIntf_1_ClearScreen(uint16 bkColor);
void MyTFTIntf_1_FillScreen(uint16 XL, uint16 XR, uint16 YU, uint16 YD, uint16 color);
void MyTFTIntf_1_FillRectangle(uint16 poX, uint16 poY, uint16 length, uint16 width, uint16 color);
void MyTFTIntf_1_DrawHorizontalLine( uint16 poX, uint16 poY, uint16 length,uint16 color);
void MyTFTIntf_1_DrawLine( uint16 x0,uint16 y0,uint16 x1, uint16 y1,uint16 color);
void MyTFTIntf_1_DrawVerticalLine( uint16 poX, uint16 poY, uint16 length,uint16 color);
void MyTFTIntf_1_DrawRectangle(uint16 poX, uint16 poY, uint16 length, uint16 width,uint16 color);
void MyTFTIntf_1_DrawCircle(int poX, int poY, int r,uint16 color);
void MyTFTIntf_1_FillCircle(int poX, int poY, int r,uint16 color);
void MyTFTIntf_1_SetOrientation(uint8 orient);
void MyTFTIntf_1_DrawChar( uint8 ascii, uint16 poX, uint16 poY,uint16 size, uint16 fgcolor);
void MyTFTIntf_1_DrawString(char *string,uint16 poX, uint16 poY, uint16 size,uint16 fgcolor);
void MyTFTIntf_1_SetPixel(uint16 poX, uint16 poY,uint16 color);
void MyTFTIntf_1_FillBitmap(uint16 poX, uint16 poY, uint16 length, uint16 width, unsigned short *Bitmap);
void MyTFTIntf_1_Graf(uint16 XL, uint16 YU, uint16 YD, uint8  Ydata , uint8 last);
void MyTFTIntf_1_Read_SD_Picture(uint16 XL, uint16 XR, uint16 YU, uint16 YD, unsigned short *FileName);

/***************************************
*        Internal Prototypes            
*        from TFT.h file
***************************************/
void MyTFTIntf_1_WriteRegData(uint8 reg, uint16 data);
void MyTFTIntf_1_WriteIndex(uint8 reg);
void MyTFTIntf_1_WriteData(uint16 data);


/***************************************
*           API Constants               
***************************************/

#define MyTFTIntf_1_CMD_QUEUE_FULL         (0x01u)
#define MyTFTIntf_1_DATA_VALID             (0x02u)

#define MyTFTIntf_1_READ_COMMAND           (0x02u)

#define MyTFTIntf_1_DATA_ADDRESS           (0x01u)
#define MyTFTIntf_1_COMMAND_ADDRESS        (0x00u)

/* from TFT.h file *******/

#define MyTFTIntf_1_FONT_SPACE             10
#define MyTFTIntf_1_FONT_X                 16
#define MyTFTIntf_1_FONT_Y                 8

//Basic Colors
#define MyTFTIntf_1_RED	 	            0xf800
#define MyTFTIntf_1_GREEN	                0x07e0
#define MyTFTIntf_1_BLUE	                0x001f
#define MyTFTIntf_1_BLACK	                0x0000
#define MyTFTIntf_1_YELLOW	                0xffe0
#define MyTFTIntf_1_WHITE	                0xffff
#define MyTFTIntf_1_CYAN		            0x07ff	
#define MyTFTIntf_1_BRIGHT_RED	            0xf810	
#define MyTFTIntf_1_GRAY1		            0x8410  
#define MyTFTIntf_1_GRAY2		            0x4208  

#define MyTFTIntf_1_MIN_X	                0
#define MyTFTIntf_1_MIN_Y	                0


/***************************************
*    Enumerated Types and Parameters    
***************************************/


/***************************************
*    Initial Parameter Constants        
***************************************/

/* Set 2 less than period because di must be sampled one cycle before
*  the end of Read Low intervals.
*/ 
#define MyTFTIntf_1_READ_LOW_PULSE           (3u - 2u)   

/* Set one less than period */ 
#define MyTFTIntf_1_READ_HIGH_PULSE          (3u - 1u)


/***************************************
*             Registers                 
***************************************/

#define MyTFTIntf_1_STATUS_REG                     (* (reg8 *)  MyTFTIntf_1_StsReg__STATUS_REG)
#define MyTFTIntf_1_STATUS_PTR                     (  (reg8 *)  MyTFTIntf_1_StsReg__STATUS_REG)

#define MyTFTIntf_1_DIN_LSB_DATA_REG               (* (reg8 *)  MyTFTIntf_1_LsbReg__STATUS_REG)
#define MyTFTIntf_1_DIN_LSB_DATA_PTR               (  (reg8 *)  MyTFTIntf_1_LsbReg__STATUS_REG)

#if (MyTFTIntf_1_BUS_WIDTH == 8u)   /* 8-bit interface */
    #define MyTFTIntf_1_CMD_FIFO_REG               (* (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__F0_REG)
    #define MyTFTIntf_1_CMD_FIFO_PTR               (  (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__F0_REG)
    #define MyTFTIntf_1_DATA_FIFO_REG              (* (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__F1_REG)
    #define MyTFTIntf_1_DATA_FIFO_PTR              (  (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__F1_REG)    
    #define MyTFTIntf_1_READ_LO_PULSE_REG          (* (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__D0_REG)
    #define MyTFTIntf_1_READ_LO_PULSE_PTR          (  (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__D0_REG)
    #define MyTFTIntf_1_READ_HI_PULSE_REG          (* (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__D1_REG)
    #define MyTFTIntf_1_READ_HI_PULSE_PTR          (  (reg8 *)  MyTFTIntf_1_GraphLcd8_Lsb__D1_REG)
#else   /* 16-bit interface */
    #define MyTFTIntf_1_CMD_FIFO_REG               (* (reg8 *)  MyTFTIntf_1_GraphLcd16_Lsb__F0_REG)
    #define MyTFTIntf_1_CMD_FIFO_PTR               (  (reg8 *)  MyTFTIntf_1_GraphLcd16_Lsb__F0_REG)
    #define MyTFTIntf_1_DATA_FIFO_PTR              (  (reg16 *) MyTFTIntf_1_GraphLcd16_Lsb__F1_REG)     
    #define MyTFTIntf_1_DIN_MSB_DATA_REG           (* (reg8 *)  MyTFTIntf_1_GraphLcd16_MsbReg__STATUS_REG)
    #define MyTFTIntf_1_DIN_MSB_DATA_PTR           (  (reg8 *)  MyTFTIntf_1_GraphLcd16_MsbReg__STATUS_REG)
    #define MyTFTIntf_1_READ_LO_PULSE_REG          (* (reg8 *)  MyTFTIntf_1_GraphLcd16_Lsb__D0_REG)
    #define MyTFTIntf_1_READ_LO_PULSE_PTR          (  (reg8 *)  MyTFTIntf_1_GraphLcd16_Lsb__D0_REG)
    #define MyTFTIntf_1_READ_HI_PULSE_REG          (* (reg8 *)  MyTFTIntf_1_GraphLcd16_Lsb__D1_REG)
    #define MyTFTIntf_1_READ_HI_PULSE_PTR          (  (reg8 *)  MyTFTIntf_1_GraphLcd16_Lsb__D1_REG) 
#endif /* MyTFTIntf_1_BUS_WIDTH == 8u */

#endif /* CY_GraphicLCDIntf_MyTFTIntf_1_H */


/* [] END OF FILE */
